@@ -8,6 +8,7 @@ from inspect import getfile
 from glob import glob
 from types import ModuleType
 from pandas import DataFrame
+from typing import Optional
 
 from vnpy.event import Event, EventEngine
 from vnpy.trader.engine import BaseEngine, MainEngine
@@ -145,7 +146,6 @@ class BacktesterEngine(BaseEngine):
         size: int,
         pricetick: float,
         capital: int,
-        inverse: bool,
         setting: dict
     ) -> None:
         """"""
@@ -170,7 +170,6 @@ class BacktesterEngine(BaseEngine):
             size=size,
             pricetick=pricetick,
             capital=capital,
-            inverse=inverse,
             mode=mode
         )
 
@@ -213,7 +212,6 @@ class BacktesterEngine(BaseEngine):
         size: int,
         pricetick: float,
         capital: int,
-        inverse: bool,
         setting: dict
     ) -> bool:
         if self.thread:
@@ -234,7 +232,6 @@ class BacktesterEngine(BaseEngine):
                 size,
                 pricetick,
                 capital,
-                inverse,
                 setting
             )
         )
@@ -271,7 +268,6 @@ class BacktesterEngine(BaseEngine):
         size: int,
         pricetick: float,
         capital: int,
-        inverse: bool,
         optimization_setting: OptimizationSetting,
         use_ga: bool
     ) -> None:
@@ -296,7 +292,6 @@ class BacktesterEngine(BaseEngine):
             size=size,
             pricetick=pricetick,
             capital=capital,
-            inverse=inverse,
             mode=mode
         )
 
@@ -337,7 +332,6 @@ class BacktesterEngine(BaseEngine):
         size: int,
         pricetick: float,
         capital: int,
-        inverse: bool,
         optimization_setting: OptimizationSetting,
         use_ga: bool
     ) -> bool:
@@ -359,7 +353,6 @@ class BacktesterEngine(BaseEngine):
                 size,
                 pricetick,
                 capital,
-                inverse,
                 optimization_setting,
                 use_ga
             )
@@ -399,7 +392,7 @@ class BacktesterEngine(BaseEngine):
             if interval == "tick":
                 data: List[TickData] = self.datafeed.query_tick_history(req)
             else:
-                contract: ContractData = self.main_engine.get_contract(vt_symbol)
+                contract: Optional[ContractData] = self.main_engine.get_contract(vt_symbol)
 
                 # If history data provided in gateway, then query
                 if contract and contract.history_data:
